@@ -1,5 +1,8 @@
+import logging
 from .client import JellyClient
 
+LOG = logging.getLogger(__name__)
+LOG.propagate = False
 
 global __jelly__
 __jelly__ = None
